

String Encrypt & Decrypt
===============
This is an Encryption project that is used to encrypt/decrypt strings.

Installing
============

.. code-block:: bash

    pip install string_encoder

Usage
=====

.. code-block:: bash

    >>> from string_encoder import encode, decode
    >>> encode("Hello World")
    >>> decode("SGVsbG8gV29ybGQ=")
